@@ -26,7 +26,7 @@ def _append_one_category(args) -> list((str, str, str, str, str, str, MultiPoint
         user_id (str): id of the user whose waypoints we're processing
         category_name (str): name of the category (Stay or Track)
     Returns:
-        list[(str, str, str, str, str, str, shapely.geometry.MultiPoint)]: list of (user_id, started_at, finished_at, type_, detected_mode, purpose, geometry)
+        list((str, str, str, str, str, str, shapely.geometry.MultiPoint)): list of (user_id, started_at, finished_at, type_, detected_mode, purpose, geometry)
     """
     indexes, df, user_id, category_name = args
     res = []
